"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.gitTagDescriptor = exports.getBranchString = void 0;
var git_describe_1 = require("git-describe");
var os_1 = require("os");
var git_rev_sync_1 = require("git-rev-sync");
var getBranchString = function (clean) {
    return clean(git_rev_sync_1.branch(process.cwd()));
};
exports.getBranchString = getBranchString;
var dirtyString = function (gitInfo, clean) {
    return gitInfo.dirty ? ".SNAPSHOT." + clean(os_1.hostname()) : '';
};
var gitHash = function (gitInfo) { return gitInfo.hash.substring(1); };
var tagOrHash = function (gitInfo) {
    return gitInfo.tag ? gitInfo.tag : gitHash(gitInfo);
};
var distance = function (gitInfo) {
    return gitInfo.distance === 0 || gitInfo.distance ? gitInfo.distance + "." : '';
};
var gitTagDescriptor = function (clean) {
    var gitInfo = git_describe_1.gitDescribeSync();
    var branch = exports.getBranchString(clean);
    return {
        versionSuffix: function () {
            return gitInfo.distance !== 0 || gitInfo.dirty
                ? branch + "+" + distance(gitInfo) + gitHash(gitInfo) + dirtyString(gitInfo, clean)
                : '';
        },
        versionMain: function () {
            return gitInfo.semver ? gitInfo.semver.version : tagOrHash(gitInfo);
        },
    };
};
exports.gitTagDescriptor = gitTagDescriptor;
//# sourceMappingURL=gitTagDescriptor.js.map